summaryrefslogtreecommitdiff
path: root/libgo/mkruntimeinc.sh
diff options
context:
space:
mode:
authorIan Lance Taylor <ian@gcc.gnu.org>2019-08-28 18:27:30 +0000
committerIan Lance Taylor <ian@gcc.gnu.org>2019-08-28 18:27:30 +0000
commitfc4f90f0c8eca75fb90c736476360584f68d7ef9 (patch)
treeff64bd8a2576d7eb0b85638a14cc3a761cb72db1 /libgo/mkruntimeinc.sh
parent464969eb9b47eb2f24403c74c16769a58dbaa638 (diff)
compiler, runtime: provide index information on bounds check failure
This implements https://golang.org/cl/161477 in the gofrontend. Updates golang/go#30116 Reviewed-on: https://go-review.googlesource.com/c/gofrontend/+/191881 From-SVN: r274998
Diffstat (limited to 'libgo/mkruntimeinc.sh')
-rwxr-xr-xlibgo/mkruntimeinc.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/libgo/mkruntimeinc.sh b/libgo/mkruntimeinc.sh
index cd95595c731..d29da9b6846 100755
--- a/libgo/mkruntimeinc.sh
+++ b/libgo/mkruntimeinc.sh
@@ -15,14 +15,15 @@ rm -f runtime.inc.tmp2 runtime.inc.tmp3
# types and should not be exported back to C
# semt is a Go translation of the C type sem_t; it fails to convert on
# some systems and need not be exported back to C.
# sigset conflicts with system type sigset on AIX, so we need to rename it
grep -v "#define _" ${IN} | grep -v "#define [cm][01234] " | grep -v "#define empty " | grep -v "#define \\$" > runtime.inc.tmp2
for pattern in '_[GP][a-z]' _Max _Lock _Sig _Trace _MHeap _Num
do
grep "#define $pattern" ${IN} >> runtime.inc.tmp2
done
-TYPES="_Complex_lock _Reader_lock semt"
+TYPES="_Complex_lock _Reader_lock semt boundsError"
for TYPE in $TYPES
do
sed -e '/struct '${TYPE}' {/,/^}/s/^.*$//' runtime.inc.tmp2 > runtime.inc.tmp3;
@@ -15,14 +15,15 @@ rm -f runtime.inc.tmp2 runtime.inc.tmp3
# semt is a Go translation of the C type sem_t; it fails to convert on
# some systems and need not be exported back to C.
-# sigset conflicts with system type sigset on AIX, so we need to rename it
+# sigset conflicts with system type sigset on AIX, so we need to rename it.
+# boundsError has a field name that is a C keyword, and we don't need it.
grep -v "#define _" ${IN} | grep -v "#define [cm][01234] " | grep -v "#define empty " | grep -v "#define \\$" > runtime.inc.tmp2
for pattern in '_[GP][a-z]' _Max _Lock _Sig _Trace _MHeap _Num